@@ -1,11 +1,11 @@
 #
 #   TTR: Technical Trading Rules
 #
-#   Copyright (C) 2007-2012  Joshua M. Ulrich
+#   Copyright (C) 2007-2013  Joshua M. Ulrich
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -17,6 +17,40 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+#'Parabolic Stop-and-Reverse
+#'
+#'The Parabolic Stop-and-Reverse calculates a trailing stop.  Developed by J.
+#'Welles Wilder.
+#'
+#'The calculation for the SAR is quite complex.  See the URLs in the references
+#'section for calculation notes.
+#'
+#'The SAR assumes that you are always in the market, and calculates the Stop
+#'And Reverse point when you would close a long position and open a short
+#'position or vice versa.
+#'
+#'@param HL Object that is coercible to xts or matrix and contains High-Low
+#'prices.
+#'@param accel accel[1]: Acceleration factor.\cr accel[2]: Maximum acceleration
+#'factor.
+#'@return A object of the same class as \code{HL} or a vector (if
+#'\code{try.xts} fails) containing the Parabolic Stop and Reverse values.
+#'@author Joshua Ulrich
+#'@seealso See \code{\link{ATR}} and \code{\link{ADX}}, which were also
+#'developed by Welles Wilder.
+#'@references The following site(s) were used to code/document this
+#'indicator:\cr
+#'\url{http://www.linnsoft.com/tour/techind/sar.htm}\cr
+#'\url{http://www.fmlabs.com/reference/SAR.htm}\cr
+#'\url{http://stockcharts.com/education/IndicatorAnalysis/indic_ParaSAR.htm}\cr
+#'\url{http://www.equis.com/Customer/Resources/TAAZ/?c=3&p=87}
+#'@keywords ts
+#'@examples
+#'
+#' data(ttrc)
+#' sar <- SAR(ttrc[,c("High","Low")])
+#'
+#'@export
 "SAR" <-
 function(HL, accel=c(.02,.2)) {
 
@@ -26,11 +60,6 @@ function(HL, accel=c(.02,.2)) {
   # accel[1] = acceleration factor
   # accel[2] = maximum acceleration factor
 
-  # http://www.linnsoft.com/tour/techind/sar.htm
-  # http://www.fmlabs.com/reference/SAR.htm
-  # http://stockcharts.com/education/IndicatorAnalysis/indic_ParaSAR.htm
-  # http://www.equis.com/Customer/Resources/TAAZ/?c=3&p=87
-
   # WISHLIST:
   # Determine signal based on DM+/DM- for first bar
   # If sig[1]==1, then ep[1]==high; if sig[1]==-1, then ep[1]==low
@@ -48,8 +77,11 @@ function(HL, accel=c(.02,.2)) {
   # Leading NAs are handled in the C code
   HL.na <- xts:::naCheck(HL, 0)
 
+  # Gap for inital SAR
+  initGap <- sd(drop(coredata(HL[,1] - HL[,2])), na.rm=TRUE)
+
   # Call C routine
-  sar <- .Call("sar", HL[,1], HL[,2], accel, PACKAGE = "TTR")
+  sar <- .Call("sar", HL[,1], HL[,2], accel, initGap, PACKAGE = "TTR")
 
   reclass( sar, HL )
 }
